@@ -112,9 +112,8 @@ ResPrintExtDev(outextfile, devices)
     FILE	*outextfile;
     RDev	*devices;
 {
-    TileType t;
     char *subsName;
-    ExtDevice *devptr;
+    ExtDevice *devptr, *devtest;
 
     for (; devices != NULL; devices = devices->nextDev)
     {
@@ -122,8 +121,7 @@ ResPrintExtDev(outextfile, devices)
 	{
 	    if (ResOptionsFlags & ResOpt_DoExtFile)
 	    {
-		t = devices->layout->rd_devtype;
-		devptr = ExtCurStyle->exts_device[t];
+		devptr = devices->rs_devptr;
 		subsName = devptr->exts_deviceSubstrateName;
 
 #ifdef MAGIC_WRAPPER
